#ifndef FORMHEADERTYPE1_H
#define FORMHEADERTYPE1_H

#include <QWidget>

namespace Ui {
class FormHeaderType1;
}

class FormHeaderType1 : public QWidget
{
    Q_OBJECT

public:
    explicit FormHeaderType1(QWidget *parent = nullptr);
    ~FormHeaderType1();

    virtual void resizeEvent(QResizeEvent *event);

    virtual void enterEvent(QEvent *event);
    virtual void leaveEvent(QEvent *event);

    virtual void mousePressEvent(QMouseEvent *event);
    virtual void mouseReleaseEvent(QMouseEvent *event);

    void Unselect();
    void Select(int nOrder);

    void SetID(int nID);
    int GetID();
    int GetOrder();

    void SetHeaderText(QString& strText);



protected:
    int m_nID;
    int m_nOrder;

signals:
    void Clicked(int nID);

private:
    Ui::FormHeaderType1 *ui;
};

#endif // FORMHEADERTYPE1_H
